.. :changelog:

History
-------

2.2.1
++++++++++++++++++
* Rename package to CURP Suite
* Write test suite with hypothesis
* Add more comprehensive CURP validation
* Add CURP data analysis and extraction
* Change public API

1.1.0
++++++++++++++++++
* First release of then CURPValidator
* Add GPLv2 License
